# Tested working in:
# Python 3.7.3
# Python 2.7.16
# Python 2.6.6
import sys
import json

try:
        # python3
        from urllib.request import Request
        from urllib.request import urlopen
        from urllib.error import HTTPError
        from urllib.error import URLError
except ImportError:
        # python2
        from urllib2 import Request
        from urllib2 import urlopen
        from urllib2 import HTTPError
        from urllib2 import URLError

try:
        # python3
        from json.decoder import JSONDecodeError
except:
        # python2
        JSONDecodeError = ValueError

def hello():
        print("Hello, World!")

if __name__ == "__main__":
        hello()


from distutils.core import setup
import io

# Read the contents of README.md
with io.open('README.md', encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='triggersms',
    version='0.1.3',
    description='TriggerSMS is a Python package for sending data to the TriggerSMS API.',
    long_description=long_description,
    long_description_content_type='text/markdown',
    packages=['triggersms'],
    license='MIT',
    classifiers=[
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Operating System :: OS Independent',
    ],
    python_requires='>=2.6.6',
)
